Emperor

## Downloading

Emperor is a python package hosted in GitHub that relies on NumPy, scikit-bio and qcli.

Download Stable Version Download Development Version

To clone the git repository directly into your machine:

    git clone git://github.com/biocore/emperor.git

## Installing

To perform a global installation of Emperor, execute the following command from a terminal session:

    python setup.py install

If you do not want to do a global installation, you will have to add the Emperor scripts and libraries to the `PATH` and `PYTHONPATH` environment variables. To add these variables to your `.bash_profile` issue the following terminal commands:

    echo "export PATH=$HOME/emperor_bin/:$PATH" >> ~/.bash_profile
    echo "export PYTHONPATH=$HOME/emperor_lib/:$PYTHONPATH" >> ~/.bash_profile
    python setup.py install --install-scripts=~/emperor_bin/ --install-purelib=~/emperor_lib/ --install-lib=~/emperor_lib/

Alternatively Emperor can be installed from the Python Package Index (PyPi) using either conda (note that this method will be notably faster):

    conda install scikit-bio
    pip install emperor

or using pip:

    pip install numpy
    pip install emperor

## Verifying your installation

To test for a correct installation, open a new terminal window and issue the following command to see the help of `make_emperor.py`:

    make_emperor.py -h
    Usage: make_emperor.py [options] {-i/--input_coords INPUT_COORDS -m/--map_fp MAP_FP}

    [] indicates optional input (order unimportant)
    {} indicates required input (order unimportant)

    This script automates the creation  of three-dimensional PCoA plots to be visualized with Emperor using Google Chrome.

    Example usage:
    Print help message and exit
     make_emperor.py -h

    ...